﻿using System;
using System.ComponentModel;
using CodeSnippet.Properties;

namespace CodeSnippet.Options
{
    /// <summary>
    /// Localized <see cref="DescriptionAttribute"/>.
    /// </summary>
    [AttributeUsage(AttributeTargets.Field | AttributeTargets.Property)]
    public sealed class LocalizedDescriptionAttribute : DescriptionAttribute
    {
        #region Initialization
        /// <summary>
        /// Initializes a new instance of the <see cref="LocalizedDescriptionAttribute"/> class.
        /// </summary>
        /// <param name="description">The description text.</param>
        public LocalizedDescriptionAttribute(string description) : base(description)
        {
        }
        #endregion Initialization

        #region Overrides
        /// <summary>
        /// Gets the description stored in this attribute.
        /// </summary>
        /// <value></value>
        /// <returns>
        /// The description stored in this attribute.
        /// </returns>
        public override string Description
        {
            get
            {
                // Return the localized version of the given value.
                var str = Resources.ResourceManager.GetString(base.Description, Resources.Culture);
                return str ?? base.Description;
            }
        }
        #endregion Overrides
    }
}